==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BareMetalHostSpecFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.Taint;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.SecretReference;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BareMetalHostSpecFluent<A extends BareMetalHostSpecFluent<A>> extends Fluent<A>{
  public String getAutomatedCleaningMode();
  public A withAutomatedCleaningMode(String automatedCleaningMode);
  public Boolean hasAutomatedCleaningMode();
  
  /**
   * This method has been deprecated, please use method buildBmc instead.
   * @return The buildable object.
   */
  @Deprecated
  public BMCDetails getBmc();
  public BMCDetails buildBmc();
  public A withBmc(BMCDetails bmc);
  public Boolean hasBmc();
  public A withNewBmc(String address,String credentialsName,Boolean disableCertificateVerification);
  public BareMetalHostSpecFluent.BmcNested<A> withNewBmc();
  public BareMetalHostSpecFluent.BmcNested<A> withNewBmcLike(BMCDetails item);
  public BareMetalHostSpecFluent.BmcNested<A> editBmc();
  public BareMetalHostSpecFluent.BmcNested<A> editOrNewBmc();
  public BareMetalHostSpecFluent.BmcNested<A> editOrNewBmcLike(BMCDetails item);
  public String getBootMACAddress();
  public A withBootMACAddress(String bootMACAddress);
  public Boolean hasBootMACAddress();
  public String getBootMode();
  public A withBootMode(String bootMode);
  public Boolean hasBootMode();
  
  /**
   * This method has been deprecated, please use method buildConsumerRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getConsumerRef();
  public ObjectReference buildConsumerRef();
  public A withConsumerRef(ObjectReference consumerRef);
  public Boolean hasConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> withNewConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> withNewConsumerRefLike(ObjectReference item);
  public BareMetalHostSpecFluent.ConsumerRefNested<A> editConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> editOrNewConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> editOrNewConsumerRefLike(ObjectReference item);
  
  /**
   * This method has been deprecated, please use method buildCustomDeploy instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomDeploy getCustomDeploy();
  public CustomDeploy buildCustomDeploy();
  public A withCustomDeploy(CustomDeploy customDeploy);
  public Boolean hasCustomDeploy();
  public A withNewCustomDeploy(String method);
  public BareMetalHostSpecFluent.CustomDeployNested<A> withNewCustomDeploy();
  public BareMetalHostSpecFluent.CustomDeployNested<A> withNewCustomDeployLike(CustomDeploy item);
  public BareMetalHostSpecFluent.CustomDeployNested<A> editCustomDeploy();
  public BareMetalHostSpecFluent.CustomDeployNested<A> editOrNewCustomDeploy();
  public BareMetalHostSpecFluent.CustomDeployNested<A> editOrNewCustomDeployLike(CustomDeploy item);
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public Boolean getExternallyProvisioned();
  public A withExternallyProvisioned(Boolean externallyProvisioned);
  public Boolean hasExternallyProvisioned();
  
  /**
   * This method has been deprecated, please use method buildFirmware instead.
   * @return The buildable object.
   */
  @Deprecated
  public FirmwareConfig getFirmware();
  public FirmwareConfig buildFirmware();
  public A withFirmware(FirmwareConfig firmware);
  public Boolean hasFirmware();
  public A withNewFirmware(Boolean simultaneousMultithreadingEnabled,Boolean sriovEnabled,Boolean virtualizationEnabled);
  public BareMetalHostSpecFluent.FirmwareNested<A> withNewFirmware();
  public BareMetalHostSpecFluent.FirmwareNested<A> withNewFirmwareLike(FirmwareConfig item);
  public BareMetalHostSpecFluent.FirmwareNested<A> editFirmware();
  public BareMetalHostSpecFluent.FirmwareNested<A> editOrNewFirmware();
  public BareMetalHostSpecFluent.FirmwareNested<A> editOrNewFirmwareLike(FirmwareConfig item);
  public String getHardwareProfile();
  public A withHardwareProfile(String hardwareProfile);
  public Boolean hasHardwareProfile();
  
  /**
   * This method has been deprecated, please use method buildImage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Image getImage();
  public Image buildImage();
  public A withImage(Image image);
  public Boolean hasImage();
  public A withNewImage(String checksum,String checksumType,String format,String url);
  public BareMetalHostSpecFluent.ImageNested<A> withNewImage();
  public BareMetalHostSpecFluent.ImageNested<A> withNewImageLike(Image item);
  public BareMetalHostSpecFluent.ImageNested<A> editImage();
  public BareMetalHostSpecFluent.ImageNested<A> editOrNewImage();
  public BareMetalHostSpecFluent.ImageNested<A> editOrNewImageLike(Image item);
  public SecretReference getMetaData();
  public A withMetaData(SecretReference metaData);
  public Boolean hasMetaData();
  public A withNewMetaData(String name,String namespace);
  public SecretReference getNetworkData();
  public A withNetworkData(SecretReference networkData);
  public Boolean hasNetworkData();
  public A withNewNetworkData(String name,String namespace);
  public Boolean getOnline();
  public A withOnline(Boolean online);
  public Boolean hasOnline();
  public String getPreprovisioningNetworkDataName();
  public A withPreprovisioningNetworkDataName(String preprovisioningNetworkDataName);
  public Boolean hasPreprovisioningNetworkDataName();
  
  /**
   * This method has been deprecated, please use method buildRaid instead.
   * @return The buildable object.
   */
  @Deprecated
  public RAIDConfig getRaid();
  public RAIDConfig buildRaid();
  public A withRaid(RAIDConfig raid);
  public Boolean hasRaid();
  public BareMetalHostSpecFluent.RaidNested<A> withNewRaid();
  public BareMetalHostSpecFluent.RaidNested<A> withNewRaidLike(RAIDConfig item);
  public BareMetalHostSpecFluent.RaidNested<A> editRaid();
  public BareMetalHostSpecFluent.RaidNested<A> editOrNewRaid();
  public BareMetalHostSpecFluent.RaidNested<A> editOrNewRaidLike(RAIDConfig item);
  
  /**
   * This method has been deprecated, please use method buildRootDeviceHints instead.
   * @return The buildable object.
   */
  @Deprecated
  public RootDeviceHints getRootDeviceHints();
  public RootDeviceHints buildRootDeviceHints();
  public A withRootDeviceHints(RootDeviceHints rootDeviceHints);
  public Boolean hasRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> withNewRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> withNewRootDeviceHintsLike(RootDeviceHints item);
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> editRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHintsLike(RootDeviceHints item);
  public A addToTaints(Integer index,Taint item);
  public A setToTaints(Integer index,Taint item);
  public A addToTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A addAllToTaints(Collection<Taint> items);
  public A removeFromTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A removeAllFromTaints(Collection<Taint> items);
  public List<Taint> getTaints();
  public Taint getTaint(Integer index);
  public Taint getFirstTaint();
  public Taint getLastTaint();
  public Taint getMatchingTaint(Predicate<Taint> predicate);
  public Boolean hasMatchingTaint(Predicate<Taint> predicate);
  public A withTaints(List<Taint> taints);
  public A withTaints(io.fabric8.kubernetes.api.model.Taint... taints);
  public Boolean hasTaints();
  public A addNewTaint(String effect,String key,String timeAdded,String value);
  public SecretReference getUserData();
  public A withUserData(SecretReference userData);
  public Boolean hasUserData();
  public A withNewUserData(String name,String namespace);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withExternallyProvisioned();
  public A withOnline();
  public interface BmcNested<N> extends Nested<N>,BMCDetailsFluent<BareMetalHostSpecFluent.BmcNested<N>>{
    public N and();
    public N endBmc();
    
  }
  public interface ConsumerRefNested<N> extends Nested<N>,ObjectReferenceFluent<BareMetalHostSpecFluent.ConsumerRefNested<N>>{
    public N and();
    public N endConsumerRef();
    
  }
  public interface CustomDeployNested<N> extends Nested<N>,CustomDeployFluent<BareMetalHostSpecFluent.CustomDeployNested<N>>{
    public N and();
    public N endCustomDeploy();
    
  }
  public interface FirmwareNested<N> extends Nested<N>,FirmwareConfigFluent<BareMetalHostSpecFluent.FirmwareNested<N>>{
    public N and();
    public N endFirmware();
    
  }
  public interface ImageNested<N> extends Nested<N>,ImageFluent<BareMetalHostSpecFluent.ImageNested<N>>{
    public N and();
    public N endImage();
    
  }
  public interface RaidNested<N> extends Nested<N>,RAIDConfigFluent<BareMetalHostSpecFluent.RaidNested<N>>{
    public N and();
    public N endRaid();
    
  }
  public interface RootDeviceHintsNested<N> extends Nested<N>,RootDeviceHintsFluent<BareMetalHostSpecFluent.RootDeviceHintsNested<N>>{
    public N and();
    public N endRootDeviceHints();
    
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BareMetalHostSpecFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.Taint;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.SecretReference;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BareMetalHostSpecFluent<A extends BareMetalHostSpecFluent<A>> extends Fluent<A>{
  public String getAutomatedCleaningMode();
  public A withAutomatedCleaningMode(String automatedCleaningMode);
  public Boolean hasAutomatedCleaningMode();
  
  /**
   * This method has been deprecated, please use method buildBmc instead.
   * @return The buildable object.
   */
  @Deprecated
  public BMCDetails getBmc();
  public BMCDetails buildBmc();
  public A withBmc(BMCDetails bmc);
  public Boolean hasBmc();
  public A withNewBmc(String address,String credentialsName,Boolean disableCertificateVerification);
  public BareMetalHostSpecFluent.BmcNested<A> withNewBmc();
  public BareMetalHostSpecFluent.BmcNested<A> withNewBmcLike(BMCDetails item);
  public BareMetalHostSpecFluent.BmcNested<A> editBmc();
  public BareMetalHostSpecFluent.BmcNested<A> editOrNewBmc();
  public BareMetalHostSpecFluent.BmcNested<A> editOrNewBmcLike(BMCDetails item);
  public String getBootMACAddress();
  public A withBootMACAddress(String bootMACAddress);
  public Boolean hasBootMACAddress();
  public String getBootMode();
  public A withBootMode(String bootMode);
  public Boolean hasBootMode();
  
  /**
   * This method has been deprecated, please use method buildConsumerRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getConsumerRef();
  public ObjectReference buildConsumerRef();
  public A withConsumerRef(ObjectReference consumerRef);
  public Boolean hasConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> withNewConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> withNewConsumerRefLike(ObjectReference item);
  public BareMetalHostSpecFluent.ConsumerRefNested<A> editConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> editOrNewConsumerRef();
  public BareMetalHostSpecFluent.ConsumerRefNested<A> editOrNewConsumerRefLike(ObjectReference item);
  
  /**
   * This method has been deprecated, please use method buildCustomDeploy instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomDeploy getCustomDeploy();
  public CustomDeploy buildCustomDeploy();
  public A withCustomDeploy(CustomDeploy customDeploy);
  public Boolean hasCustomDeploy();
  public A withNewCustomDeploy(String method);
  public BareMetalHostSpecFluent.CustomDeployNested<A> withNewCustomDeploy();
  public BareMetalHostSpecFluent.CustomDeployNested<A> withNewCustomDeployLike(CustomDeploy item);
  public BareMetalHostSpecFluent.CustomDeployNested<A> editCustomDeploy();
  public BareMetalHostSpecFluent.CustomDeployNested<A> editOrNewCustomDeploy();
  public BareMetalHostSpecFluent.CustomDeployNested<A> editOrNewCustomDeployLike(CustomDeploy item);
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public Boolean getExternallyProvisioned();
  public A withExternallyProvisioned(Boolean externallyProvisioned);
  public Boolean hasExternallyProvisioned();
  
  /**
   * This method has been deprecated, please use method buildFirmware instead.
   * @return The buildable object.
   */
  @Deprecated
  public FirmwareConfig getFirmware();
  public FirmwareConfig buildFirmware();
  public A withFirmware(FirmwareConfig firmware);
  public Boolean hasFirmware();
  public A withNewFirmware(Boolean simultaneousMultithreadingEnabled,Boolean sriovEnabled,Boolean virtualizationEnabled);
  public BareMetalHostSpecFluent.FirmwareNested<A> withNewFirmware();
  public BareMetalHostSpecFluent.FirmwareNested<A> withNewFirmwareLike(FirmwareConfig item);
  public BareMetalHostSpecFluent.FirmwareNested<A> editFirmware();
  public BareMetalHostSpecFluent.FirmwareNested<A> editOrNewFirmware();
  public BareMetalHostSpecFluent.FirmwareNested<A> editOrNewFirmwareLike(FirmwareConfig item);
  public String getHardwareProfile();
  public A withHardwareProfile(String hardwareProfile);
  public Boolean hasHardwareProfile();
  
  /**
   * This method has been deprecated, please use method buildImage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Image getImage();
  public Image buildImage();
  public A withImage(Image image);
  public Boolean hasImage();
  public A withNewImage(String checksum,String checksumType,String format,String url);
  public BareMetalHostSpecFluent.ImageNested<A> withNewImage();
  public BareMetalHostSpecFluent.ImageNested<A> withNewImageLike(Image item);
  public BareMetalHostSpecFluent.ImageNested<A> editImage();
  public BareMetalHostSpecFluent.ImageNested<A> editOrNewImage();
  public BareMetalHostSpecFluent.ImageNested<A> editOrNewImageLike(Image item);
  public SecretReference getMetaData();
  public A withMetaData(SecretReference metaData);
  public Boolean hasMetaData();
  public A withNewMetaData(String name,String namespace);
  public SecretReference getNetworkData();
  public A withNetworkData(SecretReference networkData);
  public Boolean hasNetworkData();
  public A withNewNetworkData(String name,String namespace);
  public Boolean getOnline();
  public A withOnline(Boolean online);
  public Boolean hasOnline();
  public String getPreprovisioningNetworkDataName();
  public A withPreprovisioningNetworkDataName(String preprovisioningNetworkDataName);
  public Boolean hasPreprovisioningNetworkDataName();
  
  /**
   * This method has been deprecated, please use method buildRaid instead.
   * @return The buildable object.
   */
  @Deprecated
  public RAIDConfig getRaid();
  public RAIDConfig buildRaid();
  public A withRaid(RAIDConfig raid);
  public Boolean hasRaid();
  public BareMetalHostSpecFluent.RaidNested<A> withNewRaid();
  public BareMetalHostSpecFluent.RaidNested<A> withNewRaidLike(RAIDConfig item);
  public BareMetalHostSpecFluent.RaidNested<A> editRaid();
  public BareMetalHostSpecFluent.RaidNested<A> editOrNewRaid();
  public BareMetalHostSpecFluent.RaidNested<A> editOrNewRaidLike(RAIDConfig item);
  
  /**
   * This method has been deprecated, please use method buildRootDeviceHints instead.
   * @return The buildable object.
   */
  @Deprecated
  public RootDeviceHints getRootDeviceHints();
  public RootDeviceHints buildRootDeviceHints();
  public A withRootDeviceHints(RootDeviceHints rootDeviceHints);
  public Boolean hasRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> withNewRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> withNewRootDeviceHintsLike(RootDeviceHints item);
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> editRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHints();
  public BareMetalHostSpecFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHintsLike(RootDeviceHints item);
  public A addToTaints(int index,Taint item);
  public A setToTaints(int index,Taint item);
  public A addToTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A addAllToTaints(Collection<Taint> items);
  public A removeFromTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A removeAllFromTaints(Collection<Taint> items);
  public List<Taint> getTaints();
  public Taint getTaint(int index);
  public Taint getFirstTaint();
  public Taint getLastTaint();
  public Taint getMatchingTaint(Predicate<Taint> predicate);
  public Boolean hasMatchingTaint(Predicate<Taint> predicate);
  public A withTaints(List<Taint> taints);
  public A withTaints(io.fabric8.kubernetes.api.model.Taint... taints);
  public Boolean hasTaints();
  public A addNewTaint(String effect,String key,String timeAdded,String value);
  public SecretReference getUserData();
  public A withUserData(SecretReference userData);
  public Boolean hasUserData();
  public A withNewUserData(String name,String namespace);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withExternallyProvisioned();
  public A withOnline();
  public interface BmcNested<N> extends Nested<N>,BMCDetailsFluent<BareMetalHostSpecFluent.BmcNested<N>>{
    public N and();
    public N endBmc();
    
  }
  public interface ConsumerRefNested<N> extends Nested<N>,ObjectReferenceFluent<BareMetalHostSpecFluent.ConsumerRefNested<N>>{
    public N and();
    public N endConsumerRef();
    
  }
  public interface CustomDeployNested<N> extends Nested<N>,CustomDeployFluent<BareMetalHostSpecFluent.CustomDeployNested<N>>{
    public N and();
    public N endCustomDeploy();
    
  }
  public interface FirmwareNested<N> extends Nested<N>,FirmwareConfigFluent<BareMetalHostSpecFluent.FirmwareNested<N>>{
    public N and();
    public N endFirmware();
    
  }
  public interface ImageNested<N> extends Nested<N>,ImageFluent<BareMetalHostSpecFluent.ImageNested<N>>{
    public N and();
    public N endImage();
    
  }
  public interface RaidNested<N> extends Nested<N>,RAIDConfigFluent<BareMetalHostSpecFluent.RaidNested<N>>{
    public N and();
    public N endRaid();
    
  }
  public interface RootDeviceHintsNested<N> extends Nested<N>,RootDeviceHintsFluent<BareMetalHostSpecFluent.RootDeviceHintsNested<N>>{
    public N and();
    public N endRootDeviceHints();
    
  }
  
}
